#include "sort.h"
#include <stdlib.h>
#include <string.h>
#include <stdio.h>


/*
	Bubble Sort
*/
void int_sort (unsigned int array[], unsigned int listsize) {
	unsigned int temp,i,j;

	for (i=0;i<listsize;i++) array[i]|=(i<<16);

	for (i=0;i<(listsize);i++) {
		for (j=0;j<(listsize-1);j++) {
		        if ((array[j]&0xffff) < (array[j+1]&0xffff)) {
				temp = array[j];
				array[j] = array[j+1];
				array[j+1] = temp;
			}
		}
	}
}


/*
	I have no idea what this sort is called, if it has a name
	(I just made one that I thought would work well.)
*/
void int_sort_fast (unsigned int array[], unsigned int elements) {
	unsigned int *hold_array;
	unsigned int i, x, cnt=0;
	unsigned char sizeint=sizeof(unsigned int);

	hold_array=calloc((elements+1),sizeint);

	for (i=0;i<elements;i++) array[i]|=(i<<16);

	for (i=0;i<elements;i++) {
		for (x=0;x<cnt+1;x++) {
			if ((array[i]&0xffff) > (hold_array[x]&0xffff)) {
				if (x<cnt) {
					memmove(hold_array+x+1,hold_array+x,(cnt-x+1)*sizeint);
				}
				hold_array[x]=array[i];
				break;
			}
		}
		cnt++;
	}
	memcpy(array,hold_array,elements*sizeint);
	free(hold_array);
}
